## 2.0.0

* Upgrade Facebook Android SDK to 17.0.0. 
* Upgrade Facebook iOS SDK to 17.0.0. 
  * Added [Privacy Manifests](https://developer.apple.com/documentation/bundleresources/privacy_manifest_files?content_id=AOGW6t0dwUTq7kR), see [below](#privacy-manifest-for-app-store-review-requirements).
* [Android] Fixed: `expressLogin()` invokes standard login process.
* Min Flutter SDK **2.8.0**.

See [Migration guide](UPGRADE.md#Upgrade-to-1-10).

⚠️ **BREAKING!** Important Changes in SDK v17.0 for iOS

With the release of SDK v17.0 for iOS, there are significant changes to the login behavior and token validation process:

1. **Limited Login Mode**: If the user has not granted the AdvertiserTracking permission 
([Apple documentation](https://developer.apple.com/documentation/apptrackingtransparency), [Facebook documentation](https://www.facebook.com/business/help/365087497929660)), 
the login process will now enter a Limited Login mode. This mode is indicated by the `isLimitedLogin` field in the `AccessToken` object.
2. **Access Token in Limited Login Mode**: In Limited Login mode, the access token is not valid and will **fail server-side verification**. 
Additionally, it will not permit Graph API requests. For Limited Login you need to validate OIDC token.
3. **OIDC Token Validation**: the OIDC Token will be available in the new `authenticationToken` field in the `AccessToken`. 
In Limited Login mode you should validate this token for the server-side verification. 
Learn more about token validation in the [documentation](https://developers.facebook.com/docs/facebook-login/limited-login/token/validating).
4. **Profile Image URL**: In Limited Login mode, the `getProfileImageUrl()` method will ignore size parameters. 
This limitation arises because we can't execute API calls, thus only a 100x100 image from the JWT authentication token can be used.

For detailed insights into these changes, please refer to the [blog post](https://developers.facebook.com/blog/post/2024/03/28/changes-made-to-fb-login-sdk/) and the documentation on [Limited Login](https://developers.facebook.com/docs/facebook-login/limited-login).

You can also check out the following issues in the Facebook iOS SDK repository:
- [App switches to limited login (#2375)](https://github.com/facebook/facebook-ios-sdk/issues/2375)
- [The accessToken generated by SDK 17.0.0 is Invalid... (#2365)](https://github.com/facebook/facebook-ios-sdk/issues/2365)

### Privacy Manifest for App Store Review requirements

Additional guidance for developers from Facebook [documentation](https://developers.facebook.com/docs/ios/):

* Our Privacy Manifest only provides information collected by default and the SDKs that depend on the Core SDK for functionality may restate the data usage details of the Core SDK. Some app developers may choose to send us more or less information in code, or via the Events Manager or through Advanced matching functionality. These developers will need to provide details around additional data usage details in their Privacy Manifest or App Store Privacy Labels in accordance with their own practices. Refer to the following article for more information on additional data that may be sent by developers through Meta’s SDKs.
* Note that we do not attempt to associate all collected data with Meta users.
* We have pre-populated the tracking domain field for the FB SDK in the Privacy Manifest to help ensure that our services continue to function properly. We do not advise manually adding domains. Listing “www.facebook.com” or subdomains of “facebook.com” in the tracking domain field of a Privacy Manifest may break functionality.

**Note:** Developers can find additional details around the tracking domain field in the Privacy Manifests for Meta SDKs. What is pre-populated in the tracking domain field is intended to receive traffic when a user has provided AppTrackingTransparency (ATT) permission to the app. If our check determines that a request or event from an iOS14.5+ device lacks ATT permission, then usage of such data will be restricted and we will use privacy preserving methods (like those available in [Aggregated Event Measurement]()) to remove or combine information before delivering or measuring ads.

## 1.9.0

* Upgrade Facebook Android SDK to 16.2.0. 
* Upgrade Facebook iOS SDK to 16.2.1. 

See [Migration guide](UPGRADE.md#Upgrade-to-1-9).

## 1.8.0

* Upgrade Facebook Android SDK to 16.0.1. 
* Upgrade Facebook iOS SDK to 16.0.1. 

See [Migration guide](UPGRADE.md#Upgrade-to-1-8).

## 1.7.0

* Upgrade Facebook Android SDK to 15.1.0.
  * ⚠️ The minimum supported version of Android is now **5.0** (API 21).
* Upgrade Facebook iOS SDK to 15.1.0. Thanks to [@hamzaalmahdi](https://github.com/hamzaalmahdi).
  * ⚠️ The minimum supported version of iOS is now **12.0**.
* Added Instagram permissions: `instagram_basic` and `instagram_content_publish`. Thanks to [@vhnum](https://github.com/vhnum).
* Fixed compatibility issue with Flutter 3.3.9.

See [Migration guide](UPGRADE.md#Upgrade-to-1-7).

## 1.6.2

* [Android] Migrate from `jcenter()` to `mavenCentral()`.
* **Fixed**: Compilation error `Could not resolve com.facebook.android:...`.

## 1.6.1

* Upgrade Facebook Android SDK to 14.1.1.
* Added new [Problem solving](README.md#problem-solving) section in README.

## 1.6.0

* Upgrade Facebook iOS SDK to 14.1.
* Upgrade Facebook Android SDK to 14.1.

See [Migration guide](UPGRADE.md#Upgrade-to-1-6).

## 1.5.0+1

**Fixed**: Don't compile for iOS.

* Upgrade Facebook iOS SDK to 14.

If you're upgrading from **1.5.0** - please follow to 
[Migration guide](UPGRADE.md#Upgrade-to-1-5) to version 1.5
once again.

## 1.5.0

⛔️ May not compile for iOS! Use one of the next versions ⛔️ 

* Upgrade to Facebook SDK 13.2.
  * ⚠️ The minimum supported version of iOS is now **11.0**.

See [Migration guide](UPGRADE.md#Upgrade-to-1-5).

## 1.4.1

* **Fixed**: Exception on parse Access Token if Facebook returns extremely high expiry timestamps for expires. Thanks to [@rogiervandenberg](https://github.com/rogiervandenberg).

## 1.4.0+1

* Update README and Example.

## 1.4.0

* Fix warnings and deprecation messages.
* **BREAKING** Full remove of Android embedding v1 support. 
This will not affect most of developers. See [Readme](README.md#minimum-requirements).

## 1.3.0

* Upgrade to Facebook SDK 12.3.
* Add Client Token support.

See [Migration guide](UPGRADE.md#Upgrade-to-1-3).

## 1.2.1

* Added `user_link` permission. Thanks to [@YuriNagy01](https://github.com/YuriNagy01).

## 1.2.0+1

* Readme: section about setup permissions for Facebook app. Thanks to [@SF-97](https://github.com/SF-97).

## 1.2.0

* Upgrade to Facebook SDK 12. See [Migration guide](UPGRADE.md#Upgrade-to-1-2).
  * ⚠️ The minimum supported version of iOS is now **10.0**.

## 1.1.0

* Upgrade to Facebook SDK 11. See [Migration guide](UPGRADE.md#Upgrade-to-1-1).
* Remove upper bound for Flutter constraint in pubspec.

## 1.0.1

* **Fixed**: App Events use the correct token if none have been provided manually (Facebook SDK 9.1). Thanks to [@shemhazai](https://github.com/shemhazai).

## 1.0.0

* Flutter 2.0.0.

## 1.0.0-nullsafety.1

* Migrated to null safety.

## 0.5.0

* Upgrade to Facebook SDK 9 (with new Graph API version). See [Migration guide](UPGRADE.md#Upgrade-to-0-5).

## 0.4.2+3

* Readme: update `FacebookLoginStatus` values. Thanks to [@mean-cj](https://github.com/mean-cj).

## 0.4.2+2

* Upgrade `innim_lint` to 0.1.5.

## 0.4.2+1

* Upgrade `innim_lint` to 0.1.4. Refactoring.
* Update [list_ext](https://pub.dev/packages/list_ext) dependency.

## 0.4.2

* Use [innim_lint](https://pub.dev/packages/innim_lint) analysis options.

## 0.4.1

* Added permissions `pages_manage_posts`, `pages_read_engagement` ([PR #37](https://github.com/Innim/flutter_login_facebook/pull/37)). Thanks to [@rogiervandenberg](https://github.com/rogiervandenberg).

## 0.4.0+1

* Added [Express Login](https://developers.facebook.com/docs/facebook-login/android/#expresslogin) for Android ([PR #27](https://github.com/Innim/flutter_login_facebook/pull/27)). Thanks to [@atrope](https://github.com/atrope).

## 0.3.0

* Upgrade to Facebook SDK >8.

## 0.2.1+1

* Readme: fixes in code example and typos.

## 0.2.1

* **Fixed**: Crash on iOS 10.

## 0.2.0+1

* Readme: add information about usage `getProfileImageUrl()`.

## 0.2.0

* Method to get user profile image.

## 0.1.2+4

* **Fixed:** Plugin may break some other libraries ([PR #8](https://github.com/Innim/flutter_login_facebook/pull/8)). Thanks to [@spiritinlife](https://github.com/spiritinlife).

## 0.1.2+3

* **Fixed:** intercept all open urls and launches, even though it can't be handled. 
* Minor readme improvements.

## 0.1.2+2

* Readme: fix links urls.
* Readme: fix some errors in text.
* Readme: Medium article link.

## 0.1.2+1

* Readme: add log in error handling.
* Fixed mistake in Readme.

## 0.1.2

* An ability to get user email (if have permissions).
* Add `declinedPermissions` in `AccessToken`.

## 0.1.1+1

* [android] Fixed: reset activity is never called.

## 0.1.1

* Add error information for login failure.
* Readme: add information about additional key hashes.
* Mute exception during get profile.

## 0.1.0+1

* More detailed description.

## 0.1.0

* Core functionality (iOS/Android).
